@@ -11,11 +11,14 @@ c   This is the interface to draw new volumes.
       record /epPos/ p(*)  ! output.   position given in local coord.
 
 c      
-      if(comp.struc(1:8) .eq. 'sqpipe') then
-         call epDraw_sqpipe(comp, p, n)
-      elseif(comp.struc(1:8) .eq. 'ciecone') then
-         call epDraw_ciecone(comp, p, n)
-c---  elseif(comp.struc(1:8) .eq. '%2') then
+      integer uscl
+
+      call epseeUnderScore(comp.struc, uscl)
+      if(comp.struc(1:uscl) .eq. 'octagon') then
+         call epDraw_octagon(comp, p, n)
+      elseif(comp.struc(1:uscl) .eq. 'honeycomb') then
+         call epDraw_honeycomb(comp, p, n)
+c---  elseif(comp.struc(1:uscl) .eq. '%2') then
 c---     call epDraw_%2(comp, p, n)
       else
          call cerrorMsg(comp.struc(1:8), 1)
