@@ -74,4 +74,9 @@
       !  max # of energy nodes at which exact cross-sections 
       !  are given for pair creation by muon at low eneries
       !  (3 GeV to 1500 GeV)
+#define MAXHEAVYCHG  30
+      !  max heavy charge treatable by SRIM data when dE/dx is calculated
+#define MAX_SRIMMEDIA  3
+      !  max # of  medias for which SRIM data can be applied. 
+#define MAX_STRUCCHR  12
 #endif
