@@ -11,7 +11,10 @@
                                 !  F is used to compare analytic calc.
           logical LPMeffect     !  T(default). LPM is effective else off 
           logical TimeStruc     !  
-          logical Moliere       ! Moliere's scattering  or  Gaussian
+c          logical Moliere       ! Moliere's scattering  or  Gaussian
+          integer Moliere       !  0--> Guass, 1-->Old Moliere 2-->Moliere +
+                                !   sqrt( (sin teta)/teta) rejection
+                                !  3--> +  Goudsmit & Saunderson
           real*8  EminElec      ! e-'s E < EminElec is discarded
           real*8  EminGamma     ! Egamma < EminGamma is  discarded
 	  real*8  EminH         ! Emin of Hadron/mu K.E/n 
@@ -20,6 +23,8 @@
           real*8 ElowerBndPair  ! Pair creation is neglected for Eg< this E
           real*8 EupperBndCS    ! Compton scattering is neglected Eg> this E
           integer IncGp         ! Include gp interactions or not
+                                ! 0--> no. 1--> sofia 2--> old method
+                                ! 3--> Eg<2.5GeV ->old else sofia D= 2
           logical Trace         ! how to take trace info.
           real*8 TraceErg(6)    ! a,b,c,d,e,f; energy range of trace particles 
                                 ! (a, b), (c,d), (e,f) GeV are target region
@@ -66,8 +71,48 @@
                                 ! 12--> on fly but scinti light tracing is at
                                 !   end of each event
                                 ! 21--> output data for Light=22
-                                ! 22--> read data by Light=21 and do ray tracing
-           
+                                ! 22--> read data by Light=21 and do ray tracing 
+         integer AutoEmin       ! 
+                                ! 0-> no adjustment so given EminGamma,
+                                ! EminElec, RecoilKEmin are used.
+                                ! 1-> autoadjust Emin and recoil min energy
+                                ! by using min thickness of media. 
+                                ! 2--> same as above but minimum is little bit
+                                !  higher. When ptcl energy becomes lower than
+                                !  the min, it's residual range is computed
+                                ! and if the length to the boundary is > the range,
+                                ! particles is judged dead and kinetic energy is absorbed.
+   		   	        ! (but pbar, e+ nbar are exeption; they are normally traced
+				   ! 0 energy or anihilate) 
+         integer StoppingPw    ! If positive value but Srim data is
+                               ! available for a heavy ion,  Srim data
+                               ! will be used for that heavy ion.
+                               ! To force not to use the Srim data even
+                               ! in such a case, make this vaule negative.
+                               ! The absolue value of this means:
+                               ! 1--> Effective charge with simple terms
+                               !   by Pierce and Blann is used
+                               !
+                               ! 2--> Effective charge method with complex
+                               !    terms is used for low E heavy dE/dx
+                               ! Default is 1 and seems better than 2
+                               ! at low energies.(Ek/n < 0.00* GeV)
+                               ! However, the Srim data seems better at
+                               ! such low energies.
+        
+        real(8)::SrimEmax      ! Srim data will not be used above this
+                               ! energy (KE/n GeV) even if Srim data exists
+                               ! Srim data dose not take into account the
+                               ! restricted energy loss (always total 
+                               ! energy loss including 
+                               ! knockon > RecoilKEmin.  We explicitly
+                               ! generate such high energy recoil.
+                               ! default is 0.09 GeV/n 
+        integer::PhitsXs 	! 0-->
+                                ! 
+        integer::JamXs        ! 0--> only inelastic channel with Cosmos cross-section
+    			      ! 1--> use total cross-section with //
+
         common /epTrackC/ TraceErg,
      *  Bxu,  Byu,  Bzu, Exu, Eyu, Ezu,
      *  DtMax, Tcoef, Tmin, KEmin,
@@ -77,4 +122,6 @@
      *  Eanihi, Ecut, Escat, Eabsorb, Excom1, Excom2,
      *  MagField,  ElecField, TimeStruc, EdepdEdx, Moliere, AngleB,
      *  Photo, Knckon, ALateCor, Sync,  MuNI, MuBr, MuPr, MagPair,
-     *  LPMeffect, Light
+     *  LPMeffect, Light, StoppingPw, AutoEmin,  SrimEmax,
+     *  PhitsXs, JamXs
+
