@@ -65,11 +65,15 @@ c
       if(media.sumns /= smallxs .and. media.sumns /= largexs) then
 c           prop to rhoc so next two are indep. of rhoc
          xs = media.sumns/media.nd ! mb/cm3 /(1/cm3)
-c/////////////
-c         write(*,*) ' xs=',xs, ' mb'
-c////////////
          mfp = 10.*media.rho/(media.sumns*mbTocm2)   ! in kg/m2. Not in g/cm2
                                           ! to be consistent with other  part.
+c/////////////
+c         if( pj.code == knuc) then
+c            write(*,*)' E=',pj.fm.p(4),  ' charge=',pj.charge,
+c     *      ' xs=',xs, ' mb',  ' mfp=', mfp*0.1
+c         endif
+c////////////
+         
       elseif( media.sumns == smallxs ) then
          xs = smallxs
          mfp = largexs
@@ -84,24 +88,31 @@ c////////////
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zmedia.h"
-c  #include "ZepTrackp.h"
+#include "ZepTrackp.h"
 #include "Zevhnp.h"
       record /ptcl/ pj  ! input ptcl
       record /epmedia/ media    ! input/output
 
       integer i
       real(8):: sumns,  xs
-
+c//////////
+c      real(8):: temp
+c      integer,save:: ncall = 0
+c//////////
       sumns=0. 
       do i =1, media.noOfElem
          if(pj.code >= kpion .and. pj.code <= knuc ) then
-c            if( (pj.fm.p(4)-pj.mass)  < 10.d0 )  then ! include elastic
+            if( JamXs == 1 ) then
                call ctotx(pj, media.elem(i).A,  xs)
-c            else
-c               call cinelx(pj, media.elem(i).A,  xs)
-c            endif
+            elseif( JamXs == 0 ) then
+               call cinelx(pj, media.elem(i).A, media.elem(i).Z, xs)
+            else
+               write(0,*)
+     *           ' JamXs=',JamXs, ' not usable in epixsec.f'
+               stop
+            endif
          else
-            call cinelx(pj, media.elem(i).A,  xs)
+            call cinelx(pj, media.elem(i).A,  media.elem(i).Z, xs)
          endif
          if( xs == smallxs .or. xs == largexs ) then
             sumns = xs
@@ -123,38 +134,39 @@ c            endif
       record /ptcl/ pj  ! input ptcl
       record /epmedia/ media    ! input/output
 
-      integer i
+      integer i, icon
       real(8):: sumns,  xs, u, elaxs
       integer::ka, subc, ia, iz
- 
+
       sumns=0. 
       ka = pj.code
       subc = pj.subcode
       do i =1, media.noOfElem
-         ia = media.elem(i).A
+         ia = media.elem(i).A + 0.5
          iz = media.elem(i).Z
          if( ( ka == knuc .and. subc /= antip )
      *        .or. ka == kgnuc) then
-            call rndc(u)
-            if(u <  media.elem(i).A - ia) then
-               ia = ia +1
-            endif
-            if(u < media.elem(i).Z- iz ) then
-               iz = iz + 1
-            endif
-            call cphitsXs(pj, ia, iz, elaxs,xs)
+cc            call rndc(u)
+cc            if(u <  media.elem(i).A - ia) then
+cc               ia = ia +1
+cc            endif
+!            if(u < media.elem(i).Z- iz ) then
+!               iz = iz + 1
+!            endif
+            call cphitsXs(pj, ia, iz, elaxs,xs, icon)
 cc             no need to add. xs is already total 2010.Nov.16
 ccc            xs = xs + elaxs  ! phits elaxs for heavy is 0
          else
-            if( ka >= kpion .and. ka <= knuc ) then
-               if( (pj.fm.p(4)-pj.mass)  < 10.d0 )  then ! include elastic
-                  call ctotx(pj, media.elem(i).A,  xs)
-               else
-                  call cinelx(pj, media.elem(i).A,  xs)
-               endif
-            else
-               call cinelx(pj, media.elem(i).A,  xs)
-            endif
+!            if( ka >= kpion .and. ka <= knuc ) then
+!               if( (pj.fm.p(4)-pj.mass)  < 10.d0 )  then ! include elastic
+!                  call ctotx(pj, media.elem(i).A,  xs)
+!               else
+                  call cinelx(pj, media.elem(i).A, media.elem(i).Z, xs)
+
+!               endif
+!            else
+!               call cinelx(pj, media.elem(i).A, media.elem(i).Z, xs)
+!            endif
          endif
          if( xs == smallxs .or. xs == largexs ) then
             sumns = xs
@@ -165,6 +177,7 @@ ccc            xs = xs + elaxs  ! phits elaxs for heavy is 0
          endif
       enddo
       media.sumns = sumns
+
       end
 
       subroutine epxsDpmjet3(pj, media)
@@ -186,10 +199,10 @@ c  #include "ZepTrackp.h"
             if( pj.fm.p(4) .lt.  4.1d0 ) then  ! Et is better than Ek
                call ctotx(pj, media.elem(i).A,  xs)
             else
-               call cinelx(pj, media.elem(i).A,  xs)
+               call cinelx(pj, media.elem(i).A,  media.elem(i).Z, xs)
             endif
          else
-            call cinelx(pj, media.elem(i).A,  xs)
+            call cinelx(pj, media.elem(i).A, media.elem(i).Z, xs)
          endif
          if( xs == smallxs .or. xs == largexs ) then
             sumns = xs
@@ -214,12 +227,13 @@ c  #include "ZepTrackp.h"
       record /epmedia/ media    ! input/output
 
       integer i, ia
-      real(8):: sumns,  xs, tga, u
+      real(8):: sumns,  xs, tga, u, tgz
 
 
       sumns=0. 
       do i =1, media.noOfElem
          tga = media.elem(i).A
+         tgz = media.elem(i).Z
          ia =tga 
          call rndc(u)
          if(u .lt.  tga - ia ) then
@@ -229,7 +243,7 @@ c  #include "ZepTrackp.h"
      *        pj.code == kgnuc ) then
             call cxsecQGS(pj, ia, xs)               
          else
-            call cinelx(pj, tga, xs)
+            call cinelx(pj, tga, tgz, xs)
          endif
 
          if( xs == smallxs .or. xs == largexs ) then
@@ -264,7 +278,7 @@ c  #include "ZepTrackp.h"
          if(pj.code  >= kpion .and. pj.code <= knuc ) then
             call cxsecGheisha(pj, tga,  tgz, xs)
          else
-            call cinelx(pj, tga, xs)
+            call cinelx(pj, tga, tgz, xs)
          endif
          if( xs == smallxs .or. xs == largexs ) then 
             sumns = xs
@@ -293,7 +307,7 @@ c #include "ZepTrackp.h"
 
       sumns = 0.
         do i = 1, media.noOfElem
-         call cinelx(pj, media.elem(i).A,  xs)
+         call cinelx(pj, media.elem(i).A, media.elem(i).Z, xs)
 c//////////////
 c         write(0,*) 'in othert;  xs=',xs, i,  media.noOfElem
 c////////////
@@ -312,6 +326,7 @@ c////////////
       subroutine epfixTarget(model, media)
       implicit none
 #include "Zmedia.h"
+#include "Zevhnp.h"
 c         
 c
 c       Fix the target element, 
@@ -325,7 +340,11 @@ c      xs                    they are put colA and colZ colXs
       integer  j, ia
 
 
-      if( media.noOfElem .eq. 1 ) then
+c      if( media.noOfElem .eq. 1 ) then
+      if(  media.sumns == smallxs .or.  media.sumns == largexs ) then
+         j = 1
+         media.nsigma(j) = media.sumns
+      elseif( media.noOfElem .eq. 1 ) then
          j = 1
       else
          call rndc(u)
@@ -335,20 +354,25 @@ c      xs                    they are put colA and colZ colXs
             csigma = csigma + media.nsigma(j)
             if(u .le. csigma)  goto 10
          enddo
+         write(0,*) 'medianame=', media.name, ' model=', model 
+         write(0,*) 'media.sumns=',media.sumns
+         write(0,*) 'media.noOfElem=', media.noOfElem
+         write(0,*) 'media.nsigma=',  media.nsigma(1:j)
+         write(0,*) ' u=',u, ' csigma=',csigma, ' j=',j
          call cerrorMsg('should not come here; epfixTarget',0)
       endif
  10   continue
       media.colElem = j
 c          int value is taken.
-      if(model .eq. "dpmjet3" ) then
+cc      if(model .eq. "dpmjet3" ) then
          ia = media.elem(j).A  + 0.5
-      else
-         call rndc(u)
-         ia = media.elem(j).A
-         if(u .lt. media.elem(j).A -ia ) then
-            ia = ia + 1
-         endif
-      endif
+cc      else
+cc         call rndc(u)
+cc         ia = media.elem(j).A
+cc         if(u .lt. media.elem(j).A -ia ) then
+cc            ia = ia + 1
+cc         endif
+cc      endif
       media.colZ = media.elem(j).Z
       media.colA = ia
       media.colXs = media.nsigma(j)/media.npercm3(j)
@@ -356,6 +380,7 @@ c          int value is taken.
       subroutine epfixTarget2(model, media)
       implicit none
 #include "Zmedia.h"
+#include "Zevhnp.h"
       character*16 model    ! input. Active interaction model.
 c          This may be used for small basic cross
 c     section case so that the xA cross section is
@@ -366,8 +391,10 @@ c
       integer ia
       real*8 u, sum
       integer j
-
-      if(media.noOfElem .eq. 1) then
+      if(  media.sumns == smallxs .or.  media.sumns == largexs ) then
+         j = 1
+         media.nsigma(j) = media.sumns
+      elseif(media.noOfElem .eq. 1) then
          j = 1
       else
          call rndc(u)
@@ -381,15 +408,15 @@ c
  10   continue
       media.colElem = j
 c          int value is taken.
-      if(model .eq. "dpmjet3" ) then
+!      if(model .eq. "dpmjet3" ) then
          ia = media.elem(j).A  + 0.5
-      else
-         call rndc(u)
-         ia = media.elem(j).A 
-         if(u .lt. media.elem(j).A -ia ) then
-            ia = ia + 1
-         endif
-      endif
+!      else
+!         call rndc(u)
+!         ia = media.elem(j).A 
+!         if(u .lt. media.elem(j).A -ia ) then
+!            ia = ia + 1
+!         endif
+!      endif
       media.colZ = media.elem(j).Z
       media.colA = ia
       media.colXs = media.nsigma(j)/media.npercm3(j)
